# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Session History Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.apimodels_matchmaking_history import ApimodelsMatchmakingHistory


class ApimodelsMatchmakingDetail(Model):
    """Apimodels matchmaking detail (apimodels.MatchmakingDetail)

    Properties:
        created_at: (createdAt) OPTIONAL str

        expired_at: (expiredAt) OPTIONAL str

        game_session_id: (gameSessionID) OPTIONAL str

        histories: (histories) OPTIONAL List[ApimodelsMatchmakingHistory]

        match_pool: (matchPool) OPTIONAL str

        match_rule: (matchRule) OPTIONAL str

        namespace: (namespace) OPTIONAL str

        party_session_id: (partySessionID) OPTIONAL str

        ticket_id: (ticketID) OPTIONAL str
    """

    # region fields

    created_at: str  # OPTIONAL
    expired_at: str  # OPTIONAL
    game_session_id: str  # OPTIONAL
    histories: List[ApimodelsMatchmakingHistory]  # OPTIONAL
    match_pool: str  # OPTIONAL
    match_rule: str  # OPTIONAL
    namespace: str  # OPTIONAL
    party_session_id: str  # OPTIONAL
    ticket_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: str) -> ApimodelsMatchmakingDetail:
        self.created_at = value
        return self

    def with_expired_at(self, value: str) -> ApimodelsMatchmakingDetail:
        self.expired_at = value
        return self

    def with_game_session_id(self, value: str) -> ApimodelsMatchmakingDetail:
        self.game_session_id = value
        return self

    def with_histories(
        self, value: List[ApimodelsMatchmakingHistory]
    ) -> ApimodelsMatchmakingDetail:
        self.histories = value
        return self

    def with_match_pool(self, value: str) -> ApimodelsMatchmakingDetail:
        self.match_pool = value
        return self

    def with_match_rule(self, value: str) -> ApimodelsMatchmakingDetail:
        self.match_rule = value
        return self

    def with_namespace(self, value: str) -> ApimodelsMatchmakingDetail:
        self.namespace = value
        return self

    def with_party_session_id(self, value: str) -> ApimodelsMatchmakingDetail:
        self.party_session_id = value
        return self

    def with_ticket_id(self, value: str) -> ApimodelsMatchmakingDetail:
        self.ticket_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "expired_at"):
            result["expiredAt"] = str(self.expired_at)
        elif include_empty:
            result["expiredAt"] = ""
        if hasattr(self, "game_session_id"):
            result["gameSessionID"] = str(self.game_session_id)
        elif include_empty:
            result["gameSessionID"] = ""
        if hasattr(self, "histories"):
            result["histories"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.histories
            ]
        elif include_empty:
            result["histories"] = []
        if hasattr(self, "match_pool"):
            result["matchPool"] = str(self.match_pool)
        elif include_empty:
            result["matchPool"] = ""
        if hasattr(self, "match_rule"):
            result["matchRule"] = str(self.match_rule)
        elif include_empty:
            result["matchRule"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "party_session_id"):
            result["partySessionID"] = str(self.party_session_id)
        elif include_empty:
            result["partySessionID"] = ""
        if hasattr(self, "ticket_id"):
            result["ticketID"] = str(self.ticket_id)
        elif include_empty:
            result["ticketID"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: Optional[str] = None,
        expired_at: Optional[str] = None,
        game_session_id: Optional[str] = None,
        histories: Optional[List[ApimodelsMatchmakingHistory]] = None,
        match_pool: Optional[str] = None,
        match_rule: Optional[str] = None,
        namespace: Optional[str] = None,
        party_session_id: Optional[str] = None,
        ticket_id: Optional[str] = None,
        **kwargs,
    ) -> ApimodelsMatchmakingDetail:
        instance = cls()
        if created_at is not None:
            instance.created_at = created_at
        if expired_at is not None:
            instance.expired_at = expired_at
        if game_session_id is not None:
            instance.game_session_id = game_session_id
        if histories is not None:
            instance.histories = histories
        if match_pool is not None:
            instance.match_pool = match_pool
        if match_rule is not None:
            instance.match_rule = match_rule
        if namespace is not None:
            instance.namespace = namespace
        if party_session_id is not None:
            instance.party_session_id = party_session_id
        if ticket_id is not None:
            instance.ticket_id = ticket_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsMatchmakingDetail:
        instance = cls()
        if not dict_:
            return instance
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "expiredAt" in dict_ and dict_["expiredAt"] is not None:
            instance.expired_at = str(dict_["expiredAt"])
        elif include_empty:
            instance.expired_at = ""
        if "gameSessionID" in dict_ and dict_["gameSessionID"] is not None:
            instance.game_session_id = str(dict_["gameSessionID"])
        elif include_empty:
            instance.game_session_id = ""
        if "histories" in dict_ and dict_["histories"] is not None:
            instance.histories = [
                ApimodelsMatchmakingHistory.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["histories"]
            ]
        elif include_empty:
            instance.histories = []
        if "matchPool" in dict_ and dict_["matchPool"] is not None:
            instance.match_pool = str(dict_["matchPool"])
        elif include_empty:
            instance.match_pool = ""
        if "matchRule" in dict_ and dict_["matchRule"] is not None:
            instance.match_rule = str(dict_["matchRule"])
        elif include_empty:
            instance.match_rule = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "partySessionID" in dict_ and dict_["partySessionID"] is not None:
            instance.party_session_id = str(dict_["partySessionID"])
        elif include_empty:
            instance.party_session_id = ""
        if "ticketID" in dict_ and dict_["ticketID"] is not None:
            instance.ticket_id = str(dict_["ticketID"])
        elif include_empty:
            instance.ticket_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsMatchmakingDetail]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsMatchmakingDetail]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsMatchmakingDetail,
        List[ApimodelsMatchmakingDetail],
        Dict[Any, ApimodelsMatchmakingDetail],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "createdAt": "created_at",
            "expiredAt": "expired_at",
            "gameSessionID": "game_session_id",
            "histories": "histories",
            "matchPool": "match_pool",
            "matchRule": "match_rule",
            "namespace": "namespace",
            "partySessionID": "party_session_id",
            "ticketID": "ticket_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "createdAt": False,
            "expiredAt": False,
            "gameSessionID": False,
            "histories": False,
            "matchPool": False,
            "matchRule": False,
            "namespace": False,
            "partySessionID": False,
            "ticketID": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as


from ..operations.operations import GetHealthcheckInfo
from ..operations.operations import GetHealthcheckInfoV1


@same_doc_as(GetHealthcheckInfo)
def get_healthcheck_info(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get healthcheck info (GetHealthcheckInfo)


    Properties:
        url: /healthz

        method: GET

        tags: []

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (OK)
    """
    request = GetHealthcheckInfo.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetHealthcheckInfo)
async def get_healthcheck_info_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get healthcheck info (GetHealthcheckInfo)


    Properties:
        url: /healthz

        method: GET

        tags: []

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (OK)
    """
    request = GetHealthcheckInfo.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetHealthcheckInfoV1)
def get_healthcheck_info_v1(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get healthcheck info V1 (GetHealthcheckInfoV1)


    Properties:
        url: /sessionhistory/healthz

        method: GET

        tags: []

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (OK)
    """
    request = GetHealthcheckInfoV1.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetHealthcheckInfoV1)
async def get_healthcheck_info_v1_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get healthcheck info V1 (GetHealthcheckInfoV1)


    Properties:
        url: /sessionhistory/healthz

        method: GET

        tags: []

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (OK)
    """
    request = GetHealthcheckInfoV1.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Session History Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.apimodels_party_history import ApimodelsPartyHistory


class ApimodelsPartyDetail(Model):
    """Apimodels party detail (apimodels.PartyDetail)

    Properties:
        created_at: (created_at) REQUIRED str

        histories: (histories) REQUIRED List[ApimodelsPartyHistory]

        namespace: (namespace) REQUIRED str

        party_session_id: (partySessionID) REQUIRED str

        session_template: (session_template) REQUIRED str
    """

    # region fields

    created_at: str  # REQUIRED
    histories: List[ApimodelsPartyHistory]  # REQUIRED
    namespace: str  # REQUIRED
    party_session_id: str  # REQUIRED
    session_template: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: str) -> ApimodelsPartyDetail:
        self.created_at = value
        return self

    def with_histories(
        self, value: List[ApimodelsPartyHistory]
    ) -> ApimodelsPartyDetail:
        self.histories = value
        return self

    def with_namespace(self, value: str) -> ApimodelsPartyDetail:
        self.namespace = value
        return self

    def with_party_session_id(self, value: str) -> ApimodelsPartyDetail:
        self.party_session_id = value
        return self

    def with_session_template(self, value: str) -> ApimodelsPartyDetail:
        self.session_template = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["created_at"] = str(self.created_at)
        elif include_empty:
            result["created_at"] = ""
        if hasattr(self, "histories"):
            result["histories"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.histories
            ]
        elif include_empty:
            result["histories"] = []
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "party_session_id"):
            result["partySessionID"] = str(self.party_session_id)
        elif include_empty:
            result["partySessionID"] = ""
        if hasattr(self, "session_template"):
            result["session_template"] = str(self.session_template)
        elif include_empty:
            result["session_template"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: str,
        histories: List[ApimodelsPartyHistory],
        namespace: str,
        party_session_id: str,
        session_template: str,
        **kwargs,
    ) -> ApimodelsPartyDetail:
        instance = cls()
        instance.created_at = created_at
        instance.histories = histories
        instance.namespace = namespace
        instance.party_session_id = party_session_id
        instance.session_template = session_template
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsPartyDetail:
        instance = cls()
        if not dict_:
            return instance
        if "created_at" in dict_ and dict_["created_at"] is not None:
            instance.created_at = str(dict_["created_at"])
        elif include_empty:
            instance.created_at = ""
        if "histories" in dict_ and dict_["histories"] is not None:
            instance.histories = [
                ApimodelsPartyHistory.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["histories"]
            ]
        elif include_empty:
            instance.histories = []
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "partySessionID" in dict_ and dict_["partySessionID"] is not None:
            instance.party_session_id = str(dict_["partySessionID"])
        elif include_empty:
            instance.party_session_id = ""
        if "session_template" in dict_ and dict_["session_template"] is not None:
            instance.session_template = str(dict_["session_template"])
        elif include_empty:
            instance.session_template = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsPartyDetail]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsPartyDetail]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsPartyDetail,
        List[ApimodelsPartyDetail],
        Dict[Any, ApimodelsPartyDetail],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "created_at": "created_at",
            "histories": "histories",
            "namespace": "namespace",
            "partySessionID": "party_session_id",
            "session_template": "session_template",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "created_at": True,
            "histories": True,
            "namespace": True,
            "partySessionID": True,
            "session_template": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Session History Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.models_match import ModelsMatch


class ApimodelsEventMatchHistory(Model):
    """Apimodels event match history (apimodels.EventMatchHistory)

    Properties:
        action: (action) REQUIRED str

        match_id: (matchID) REQUIRED str

        matchpool: (matchpool) REQUIRED str

        namespace: (namespace) REQUIRED str

        pod_name: (podName) REQUIRED str

        timestamp: (timestamp) REQUIRED str

        match: (match) OPTIONAL ModelsMatch

        rule_set: (ruleSet) OPTIONAL str

        tick_id: (tickID) OPTIONAL str
    """

    # region fields

    action: str  # REQUIRED
    match_id: str  # REQUIRED
    matchpool: str  # REQUIRED
    namespace: str  # REQUIRED
    pod_name: str  # REQUIRED
    timestamp: str  # REQUIRED
    match: ModelsMatch  # OPTIONAL
    rule_set: str  # OPTIONAL
    tick_id: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_action(self, value: str) -> ApimodelsEventMatchHistory:
        self.action = value
        return self

    def with_match_id(self, value: str) -> ApimodelsEventMatchHistory:
        self.match_id = value
        return self

    def with_matchpool(self, value: str) -> ApimodelsEventMatchHistory:
        self.matchpool = value
        return self

    def with_namespace(self, value: str) -> ApimodelsEventMatchHistory:
        self.namespace = value
        return self

    def with_pod_name(self, value: str) -> ApimodelsEventMatchHistory:
        self.pod_name = value
        return self

    def with_timestamp(self, value: str) -> ApimodelsEventMatchHistory:
        self.timestamp = value
        return self

    def with_match(self, value: ModelsMatch) -> ApimodelsEventMatchHistory:
        self.match = value
        return self

    def with_rule_set(self, value: str) -> ApimodelsEventMatchHistory:
        self.rule_set = value
        return self

    def with_tick_id(self, value: str) -> ApimodelsEventMatchHistory:
        self.tick_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "action"):
            result["action"] = str(self.action)
        elif include_empty:
            result["action"] = ""
        if hasattr(self, "match_id"):
            result["matchID"] = str(self.match_id)
        elif include_empty:
            result["matchID"] = ""
        if hasattr(self, "matchpool"):
            result["matchpool"] = str(self.matchpool)
        elif include_empty:
            result["matchpool"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "pod_name"):
            result["podName"] = str(self.pod_name)
        elif include_empty:
            result["podName"] = ""
        if hasattr(self, "timestamp"):
            result["timestamp"] = str(self.timestamp)
        elif include_empty:
            result["timestamp"] = ""
        if hasattr(self, "match"):
            result["match"] = self.match.to_dict(include_empty=include_empty)
        elif include_empty:
            result["match"] = ModelsMatch()
        if hasattr(self, "rule_set"):
            result["ruleSet"] = str(self.rule_set)
        elif include_empty:
            result["ruleSet"] = ""
        if hasattr(self, "tick_id"):
            result["tickID"] = str(self.tick_id)
        elif include_empty:
            result["tickID"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        action: str,
        match_id: str,
        matchpool: str,
        namespace: str,
        pod_name: str,
        timestamp: str,
        match: Optional[ModelsMatch] = None,
        rule_set: Optional[str] = None,
        tick_id: Optional[str] = None,
        **kwargs,
    ) -> ApimodelsEventMatchHistory:
        instance = cls()
        instance.action = action
        instance.match_id = match_id
        instance.matchpool = matchpool
        instance.namespace = namespace
        instance.pod_name = pod_name
        instance.timestamp = timestamp
        if match is not None:
            instance.match = match
        if rule_set is not None:
            instance.rule_set = rule_set
        if tick_id is not None:
            instance.tick_id = tick_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsEventMatchHistory:
        instance = cls()
        if not dict_:
            return instance
        if "action" in dict_ and dict_["action"] is not None:
            instance.action = str(dict_["action"])
        elif include_empty:
            instance.action = ""
        if "matchID" in dict_ and dict_["matchID"] is not None:
            instance.match_id = str(dict_["matchID"])
        elif include_empty:
            instance.match_id = ""
        if "matchpool" in dict_ and dict_["matchpool"] is not None:
            instance.matchpool = str(dict_["matchpool"])
        elif include_empty:
            instance.matchpool = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "podName" in dict_ and dict_["podName"] is not None:
            instance.pod_name = str(dict_["podName"])
        elif include_empty:
            instance.pod_name = ""
        if "timestamp" in dict_ and dict_["timestamp"] is not None:
            instance.timestamp = str(dict_["timestamp"])
        elif include_empty:
            instance.timestamp = ""
        if "match" in dict_ and dict_["match"] is not None:
            instance.match = ModelsMatch.create_from_dict(
                dict_["match"], include_empty=include_empty
            )
        elif include_empty:
            instance.match = ModelsMatch()
        if "ruleSet" in dict_ and dict_["ruleSet"] is not None:
            instance.rule_set = str(dict_["ruleSet"])
        elif include_empty:
            instance.rule_set = ""
        if "tickID" in dict_ and dict_["tickID"] is not None:
            instance.tick_id = str(dict_["tickID"])
        elif include_empty:
            instance.tick_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsEventMatchHistory]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsEventMatchHistory]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsEventMatchHistory,
        List[ApimodelsEventMatchHistory],
        Dict[Any, ApimodelsEventMatchHistory],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "action": "action",
            "matchID": "match_id",
            "matchpool": "matchpool",
            "namespace": "namespace",
            "podName": "pod_name",
            "timestamp": "timestamp",
            "match": "match",
            "ruleSet": "rule_set",
            "tickID": "tick_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "action": True,
            "matchID": True,
            "matchpool": True,
            "namespace": True,
            "podName": True,
            "timestamp": True,
            "match": False,
            "ruleSet": False,
            "tickID": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session History Service."""

__version__ = "1.12.3"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .apimodels_acquiring_ds import ApimodelsAcquiringDS
from .apimodels_acquiring_ds_wait_time import ApimodelsAcquiringDsWaitTime
from .apimodels_canceled_matchmaking_ticket import ApimodelsCanceledMatchmakingTicket
from .apimodels_created_matchmaking_ticket import ApimodelsCreatedMatchmakingTicket
from .apimodels_event_match_history import ApimodelsEventMatchHistory
from .apimodels_expired_matchmaking_ticket import ApimodelsExpiredMatchmakingTicket
from .apimodels_game_session_detail import ApimodelsGameSessionDetail
from .apimodels_game_session_detail_query_response import (
    ApimodelsGameSessionDetailQueryResponse,
)
from .apimodels_history import ApimodelsHistory
from .apimodels_match_length_duration import ApimodelsMatchLengthDuration
from .apimodels_matchmaking_detail import ApimodelsMatchmakingDetail
from .apimodels_matchmaking_detail_query_response import (
    ApimodelsMatchmakingDetailQueryResponse,
)
from .apimodels_matchmaking_history import ApimodelsMatchmakingHistory
from .apimodels_match_matchmaking import ApimodelsMatchMatchmaking
from .apimodels_match_matchmaking_ticket import ApimodelsMatchMatchmakingTicket
from .apimodels_pagination import ApimodelsPagination
from .apimodels_party_detail import ApimodelsPartyDetail
from .apimodels_party_detail_query_response import ApimodelsPartyDetailQueryResponse
from .apimodels_party_history import ApimodelsPartyHistory
from .apimodels_ticket_detail_query_response import ApimodelsTicketDetailQueryResponse
from .apimodels_ticket_observability_detail import ApimodelsTicketObservabilityDetail
from .apimodels_ticket_observability_history import ApimodelsTicketObservabilityHistory
from .apimodels_total_active_session import ApimodelsTotalActiveSession
from .apimodels_total_player_persession import ApimodelsTotalPlayerPersession
from .apimodels_x_ray_acquiring_ds_query_response import (
    ApimodelsXRayAcquiringDsQueryResponse,
)
from .apimodels_x_ray_acquiring_ds_wait_time_query_response import (
    ApimodelsXRayAcquiringDsWaitTimeQueryResponse,
)
from .apimodels_x_ray_bulk_ticket_observability_request import (
    ApimodelsXRayBulkTicketObservabilityRequest,
)
from .apimodels_x_ray_bulk_ticket_observability_response import (
    ApimodelsXRayBulkTicketObservabilityResponse,
)
from .apimodels_x_ray_canceled_matchmaking_ticket_query_response import (
    ApimodelsXRayCanceledMatchmakingTicketQueryResponse,
)
from .apimodels_x_ray_created_matchmaking_ticket_query_response import (
    ApimodelsXRayCreatedMatchmakingTicketQueryResponse,
)
from .apimodels_x_ray_expired_matchmaking_ticket_query_response import (
    ApimodelsXRayExpiredMatchmakingTicketQueryResponse,
)
from .apimodels_x_ray_matches_query_response import ApimodelsXRayMatchesQueryResponse
from .apimodels_x_ray_match_histor_query_response import (
    ApimodelsXRayMatchHistorQueryResponse,
)
from .apimodels_x_ray_match_length_duration_query_response import (
    ApimodelsXRayMatchLengthDurationQueryResponse,
)
from .apimodels_x_ray_match_matchmaking_query_response import (
    ApimodelsXRayMatchMatchmakingQueryResponse,
)
from .apimodels_x_ray_match_matchmaking_ticket_query_response import (
    ApimodelsXRayMatchMatchmakingTicketQueryResponse,
)
from .apimodels_x_ray_match_pool_pod_tick_match_response import (
    ApimodelsXRayMatchPoolPodTickMatchResponse,
)
from .apimodels_x_ray_match_pool_pod_tick_query_response import (
    ApimodelsXRayMatchPoolPodTickQueryResponse,
)
from .apimodels_x_ray_match_pool_pod_tick_result import (
    ApimodelsXRayMatchPoolPodTickResult,
)
from .apimodels_x_ray_match_pool_pod_tick_ticket_response import (
    ApimodelsXRayMatchPoolPodTickTicketResponse,
)
from .apimodels_x_ray_match_pool_query_response import (
    ApimodelsXRayMatchPoolQueryResponse,
)
from .apimodels_x_ray_match_pool_result import ApimodelsXRayMatchPoolResult
from .apimodels_x_ray_match_ticket_history import ApimodelsXRayMatchTicketHistory
from .apimodels_x_ray_match_ticket_history_query_response import (
    ApimodelsXRayMatchTicketHistoryQueryResponse,
)
from .apimodels_x_ray_ticket_matches_result import ApimodelsXRayTicketMatchesResult
from .apimodels_x_ray_ticket_observability_request import (
    ApimodelsXRayTicketObservabilityRequest,
)
from .apimodels_x_ray_ticket_observability_response import (
    ApimodelsXRayTicketObservabilityResponse,
)
from .apimodels_x_ray_ticket_query_response import ApimodelsXRayTicketQueryResponse
from .apimodels_x_ray_ticket_result import ApimodelsXRayTicketResult
from .apimodels_x_ray_total_active_session_query_response import (
    ApimodelsXRayTotalActiveSessionQueryResponse,
)
from .apimodels_x_ray_total_player_persession_avg_query_response import (
    ApimodelsXRayTotalPlayerPersessionAVGQueryResponse,
)
from .logconfig_configuration import LogconfigConfiguration
from .logconfig_configuration import LogLevelEnum as LogconfigConfigurationLogLevelEnum
from .models_alliance_rule import ModelsAllianceRule
from .models_backfill_proposal import ModelsBackfillProposal
from .models_backfill_ticket import ModelsBackfillTicket
from .models_ds_information import ModelsDSInformation
from .models_game_server import ModelsGameServer
from .models_game_session import ModelsGameSession
from .models_game_session_team import ModelsGameSessionTeam
from .models_match import ModelsMatch
from .models_matching_ally import ModelsMatchingAlly
from .models_matching_party import ModelsMatchingParty
from .models_matching_rule import ModelsMatchingRule
from .models_matchmaking_result import ModelsMatchmakingResult
from .models_match_ticket import ModelsMatchTicket
from .models_party import ModelsParty
from .models_party_member import ModelsPartyMember
from .models_party_members import ModelsPartyMembers
from .models_party_team import ModelsPartyTeam
from .models_player_data import ModelsPlayerData
from .models_proposed_proposal import ModelsProposedProposal
from .models_session_config import ModelsSessionConfig
from .models_session_configuration import ModelsSessionConfiguration
from .models_team import ModelsTeam
from .models_ticket import ModelsTicket
from .models_ticket_data import ModelsTicketData
from .models_ticket_observability import ModelsTicketObservability
from .models_ticket_status import ModelsTicketStatus
from .models_user import ModelsUser
from .response_error import ResponseError
